@@ -22,17 +22,35 @@ from .vidkl import viDKL
 def EI(rng_key: jnp.ndarray, model: Type[ExactGP],
        X: jnp.ndarray, xi: float = 0.01,
        maximize: bool = False, n: int = 1,
-       noiseless: bool = False) -> jnp.ndarray:
+       noiseless: bool = False, **kwargs) -> jnp.ndarray:
     """
     Expected Improvement
+
+    Args:
+        rng_key: JAX random number generator key
+        model: trained model
+        X: new inputs
+        xi: coefficient balancing exploration-exploitation trade-off
+        maximize: If True, assumes that BO is solving maximization problem
+        n: number of samples drawn from each MVN distribution
+           (number of distributions is equal to the number of HMC samples)
+        noiseless:
+            Noise-free prediction. It is set to False by default as new/unseen data is assumed
+            to follow the same distribution as the training data. Hence, since we introduce a model noise
+            for the training data, we also want to include that noise in our prediction.
+        **jitter:
+            Small positive term added to the diagonal part of a covariance
+            matrix for numerical stability (Default: 1e-6)
     """
     if model.mcmc is not None:
-        y_mean, y_sampled = model.predict(rng_key, X, n=n, noiseless=noiseless)
+        y_mean, y_sampled = model.predict(
+            rng_key, X, n=n, noiseless=noiseless, **kwargs)
         y_sampled = y_sampled.reshape(n * y_sampled.shape[0], -1)
         mean, sigma = y_sampled.mean(0), y_sampled.std(0)
         u = (mean - y_mean.max() - xi) / sigma
     else:
-        mean, var = model.predict(rng_key, X, noiseless=noiseless)
+        mean, var = model.predict(
+            rng_key, X, noiseless=noiseless, **kwargs)
         sigma = jnp.sqrt(var)
         u = (mean - mean.max() - xi) / sigma
     u = -u if not maximize else u
@@ -45,16 +63,34 @@ def EI(rng_key: jnp.ndarray, model: Type[ExactGP],
 def UCB(rng_key: jnp.ndarray, model: Type[ExactGP],
         X: jnp.ndarray, beta: float = .25,
         maximize: bool = False, n: int = 1,
-        noiseless: bool = False) -> jnp.ndarray:
+        noiseless: bool = False, **kwargs) -> jnp.ndarray:
     """
     Upper confidence bound
+
+    Args:
+        rng_key: JAX random number generator key
+        model: trained model
+        X: new inputs
+        beta: coefficient balancing exploration-exploitation trade-off
+        maximize: If True, assumes that BO is solving maximization problem
+        n: number of samples drawn from each MVN distribution
+           (number of distributions is equal to the number of HMC samples)
+        noiseless:
+            Noise-free prediction. It is set to False by default as new/unseen data is assumed
+            to follow the same distribution as the training data. Hence, since we introduce a model noise
+            for the training data, we also want to include that noise in our prediction.
+        **jitter:
+            Small positive term added to the diagonal part of a covariance
+            matrix for numerical stability (Default: 1e-6)
     """
     if model.mcmc is not None:
-        _, y_sampled = model.predict(rng_key, X, n=n, noiseless=noiseless)
+        _, y_sampled = model.predict(
+            rng_key, X, n=n, noiseless=noiseless, **kwargs)
         y_sampled = y_sampled.reshape(n * y_sampled.shape[0], -1)
         mean, var = y_sampled.mean(0), y_sampled.var(0)
     else:
-        mean, var = model.predict(rng_key, X, noiseless=noiseless)
+        mean, var = model.predict(
+            rng_key, X, noiseless=noiseless, **kwargs)
     delta = jnp.sqrt(beta * var)
     if maximize:
         return mean + delta
@@ -64,31 +100,68 @@ def UCB(rng_key: jnp.ndarray, model: Type[ExactGP],
 def UE(rng_key: jnp.ndarray,
        model: Type[ExactGP],
        X: jnp.ndarray, n: int = 1,
-       noiseless: bool = False) -> jnp.ndarray:
-    """Uncertainty-based exploration (aka kriging)"""
+       noiseless: bool = False,
+       **kwargs) -> jnp.ndarray:
+    """
+    Uncertainty-based exploration
+
+    Args:
+        rng_key: JAX random number generator key
+        model: trained model
+        X: new inputs
+        n: number of samples drawn from each MVN distribution
+           (number of distributions is equal to the number of HMC samples)
+        noiseless:
+            Noise-free prediction. It is set to False by default as new/unseen data is assumed
+            to follow the same distribution as the training data. Hence, since we introduce a model noise
+            for the training data, we also want to include that noise in our prediction.
+        **jitter:
+            Small positive term added to the diagonal part of a covariance
+            matrix for numerical stability (Default: 1e-6)
+    """
     if model.mcmc is not None:
-        _, y_sampled = model.predict(rng_key, X, n=n, noiseless=noiseless)
+        _, y_sampled = model.predict(
+            rng_key, X, n=n, noiseless=noiseless, **kwargs)
         y_sampled = y_sampled.mean(1)
         var = y_sampled.var(0)
     else:
-        _, var = model.predict(rng_key, X, noiseless=noiseless)
+        _, var = model.predict(
+            rng_key, X, noiseless=noiseless, **kwargs)
     return var
 
 
 def Thompson(rng_key: jnp.ndarray,
              model: Type[ExactGP],
              X: jnp.ndarray, n: int = 1,
-             noiseless: bool = False) -> jnp.ndarray:
-    """Thompson sampling"""
+             noiseless: bool = False,
+             **kwargs) -> jnp.ndarray:
+    """
+    Thompson sampling
+
+    Args:
+        rng_key: JAX random number generator key
+        model: trained model
+        X: new inputs
+        n: number of samples drawn from the randomly selected MVN distribution
+        noiseless:
+            Noise-free prediction. It is set to False by default as new/unseen data is assumed
+            to follow the same distribution as the training data. Hence, since we introduce a model noise
+            for the training data, we also want to include that noise in our prediction.
+        **jitter:
+            Small positive term added to the diagonal part of a covariance
+            matrix for numerical stability (Default: 1e-6)
+    """
     if model.mcmc is not None:
         posterior_samples = model.get_samples()
         idx = jra.randint(rng_key, (1,), 0, len(posterior_samples["k_length"]))
         samples = {k: v[idx] for (k, v) in posterior_samples.items()}
-        _, tsample = model.predict(rng_key, X, samples, n, noiseless=noiseless)
+        _, tsample = model.predict(
+            rng_key, X, samples, n, noiseless=noiseless, **kwargs)
         if n > 1:
             tsample = tsample.mean(1).squeeze()
     else:
-        _, tsample = model.sample_from_posterior(rng_key, X, n=1, noiseless=noiseless)
+        _, tsample = model.sample_from_posterior(
+            rng_key, X, n=1, noiseless=noiseless, **kwargs)
     return tsample
 
 
@@ -160,5 +233,6 @@ def obtain_samples(rng_key: jnp.ndarray, model: Type[ExactGP],
     idx = idx[:batch_size]
     samples = {k: v[idx] for (k, v) in posterior_samples.items()}
     _, y_sampled = model.predict_in_batches(
-        rng_key, X, kwargs.get("xbatch_size", 500), samples, n, noiseless=noiseless)
+        rng_key, X, kwargs.get("xbatch_size", 500), samples, n,
+        noiseless=noiseless, **kwargs)
     return y_sampled
