@@ -80,7 +80,7 @@ class viDKL(ExactGP):
         self.kernel_params = None
         self.nn_params = None
 
-    def model(self, X: jnp.ndarray, y: jnp.ndarray = None) -> None:
+    def model(self, X: jnp.ndarray, y: jnp.ndarray = None, **kwargs) -> None:
         """DKL probabilistic model"""
         # NN part
         feature_extractor = random_haiku_module(
@@ -102,7 +102,8 @@ class viDKL(ExactGP):
         k = get_kernel(self.kernel)(
             z, z,
             kernel_params,
-            noise
+            noise,
+            **kwargs
         )
         # sample y according to the standard Gaussian process formula
         numpyro.sample(
@@ -113,7 +114,8 @@ class viDKL(ExactGP):
 
     def single_fit(self, rng_key: jnp.array, X: jnp.ndarray, y: jnp.ndarray,
                    num_steps: int = 1000, step_size: float = 5e-3,
-                   print_summary: bool = True, progress_bar=True) -> None:
+                   print_summary: bool = True, progress_bar=True,
+                   **kwargs) -> None:
         """
         Optimizes parameters of a single DKL model
         """
@@ -126,6 +128,7 @@ class viDKL(ExactGP):
             loss=Trace_ELBO(),
             X=X,
             y=y,
+            **kwargs
         )
         params, _, losses = svi.run(rng_key, num_steps, progress_bar=progress_bar)
         # Get DKL parameters from the guide
@@ -139,7 +142,7 @@ class viDKL(ExactGP):
 
     def fit(self, rng_key: jnp.array, X: jnp.ndarray, y: jnp.ndarray,
             num_steps: int = 1000, step_size: float = 5e-3,
-            print_summary: bool = True, progress_bar=True):
+            print_summary: bool = True, progress_bar=True, **kwargs):
         """
         Run stochastic variational inference to learn a DKL model(s) parameters
 
@@ -155,7 +158,7 @@ class viDKL(ExactGP):
         def _single_fit(x_i, y_i):
             return self.single_fit(
                 rng_key, x_i, y_i, num_steps, step_size,
-                print_summary=False, progress_bar=False)
+                print_summary=False, progress_bar=False, **kwargs)
 
         self.X_train = X
         self.y_train = y
@@ -181,12 +184,13 @@ class viDKL(ExactGP):
                           X_new: jnp.ndarray,
                           nn_params: Dict[str, jnp.ndarray],
                           k_params: Dict[str, jnp.ndarray],
-                          noiseless: bool = False
+                          noiseless: bool = False,
+                          **kwargs
                           ) -> Tuple[jnp.ndarray, jnp.ndarray]:
         """
         Returns predictive mean and covariance at new points
         (mean and cov, where cov.diagonal() is 'uncertainty')
-        given a single set of DKL hyperparameters
+        given a single set of DKL parameters
         """
         noise = k_params["noise"]
         noise_p = noise * (1 - jnp.array(noiseless, int))
@@ -196,9 +200,9 @@ class viDKL(ExactGP):
         z_test = self.nn_module.apply(
             nn_params, jax.random.PRNGKey(0), X_new)
         # compute kernel matrices for train and test data
-        k_pp = get_kernel(self.kernel)(z_test, z_test, k_params, noise_p)
+        k_pp = get_kernel(self.kernel)(z_test, z_test, k_params, noise_p, **kwargs)
         k_pX = get_kernel(self.kernel)(z_test, z_train, k_params, jitter=0.0)
-        k_XX = get_kernel(self.kernel)(z_train, z_train, k_params, noise)
+        k_XX = get_kernel(self.kernel)(z_train, z_train, k_params, noise, **kwargs)
         # compute the predictive covariance and mean
         K_xx_inv = jnp.linalg.inv(k_XX)
         cov = k_pp - jnp.matmul(k_pX, jnp.matmul(K_xx_inv, jnp.transpose(k_pX)))
@@ -207,27 +211,29 @@ class viDKL(ExactGP):
 
     def sample_from_posterior(self, rng_key: jnp.ndarray,
                               X_new: jnp.ndarray, n: int = 1000,
-                              noiseless: bool = False
+                              noiseless: bool = False,
+                              **kwargs
                               ) -> Tuple[jnp.ndarray]:
         """
         Samples from the DKL posterior at X_new points
         """
         y_mean, K = self.get_mvn_posterior(
             self.X_train, self.y_train, X_new,
-            self.nn_params, self.kernel_params, noiseless)
+            self.nn_params, self.kernel_params, noiseless, **kwargs)
         y_sampled = dist.MultivariateNormal(y_mean, K).sample(rng_key, sample_shape=(n,))
         return y_mean, y_sampled
 
     def predict_in_batches(self, rng_key: jnp.ndarray,
                            X_new: jnp.ndarray,  batch_size: int = 100,
-                           noiseless: bool = False
+                           noiseless: bool = False,
+                           **kwargs
                            ) -> Tuple[jnp.ndarray, jnp.ndarray]:
         """
-        Make prediction at X_new with sampled DKL hyperparameters
+        Make prediction at X_new with sampled DKL parameters
         by spitting the input array into chunks ("batches") and running
         self.predict on each of them one-by-one to avoid a memory overflow
         """
-        predict_fn = lambda xi: self.predict(rng_key, xi, noiseless=noiseless)
+        predict_fn = lambda xi: self.predict(rng_key, xi, noiseless=noiseless, **kwargs)
         cat_dim = 1 if self.X_train.ndim == len(self.data_dim) + 2 else 0
         mean, var = self._predict_in_batches(
             rng_key, X_new, batch_size, cat_dim, predict_fn=predict_fn)
@@ -237,15 +243,15 @@ class viDKL(ExactGP):
 
     def predict(self, rng_key: jnp.ndarray, X_new: jnp.ndarray,
                 params: Optional[Tuple[Dict[str, jnp.ndarray]]] = None,
-                noiseless: bool = False, *args
+                noiseless: bool = False, *args, **kwargs
                 ) -> Tuple[jnp.ndarray, jnp.ndarray]:
         """
         Make prediction at X_new points using a trained DKL model(s)
 
         Args:
             rng_key: random number generator key
-            X_new: New ('test') data
-            params: Tuple with neural network weigths and kernel parameters(optional)
+            X_new: New inputs
+            params: Tuple with neural network weigths and kernel parameters (optional)
             noiseless:
                 Noise-free prediction. It is set to False by default as new/unseen data is assumed
                 to follow the same distribution as the training data. Hence, since we introduce a model noise
@@ -257,7 +263,7 @@ class viDKL(ExactGP):
 
         def single_predict(x_train_i, y_train_i, x_new_i, nnpar_i, kpar_i):
             mean, cov = self.get_mvn_posterior(
-                x_train_i, y_train_i, x_new_i, nnpar_i, kpar_i, noiseless)
+                x_train_i, y_train_i, x_new_i, nnpar_i, kpar_i, noiseless, **kwargs)
             return mean, cov.diagonal()
 
         if params is None:
@@ -278,7 +284,7 @@ class viDKL(ExactGP):
                     X_new: jnp.ndarray, num_steps: int = 1000, step_size: float = 5e-3,
                     n_models: int = 1, batch_size: int = 100, noiseless: bool = False,
                     ensemble_method: str = 'vectorized',
-                    print_summary: bool = True, progress_bar=True
+                    print_summary: bool = True, progress_bar=True, **kwargs
                     ) -> Tuple[jnp.ndarray, jnp.ndarray]:
         """
         Run SVI to learn DKL model(s) parameters and make a prediction with
@@ -307,8 +313,9 @@ class viDKL(ExactGP):
 
         def single_fit_predict(key):
             self.fit(key, X, y, num_steps, step_size,
-                     print_summary, progress_bar)
-            mean, var = self.predict_in_batches(key, X_new, batch_size, noiseless)
+                     print_summary, progress_bar, **kwargs)
+            mean, var = self.predict_in_batches(
+                key, X_new, batch_size, noiseless, **kwargs)
             return mean, var
 
         if n_models > 1 and ensemble_method not in ["vectorized", "parallel"]:
